@@ -14,6 +14,7 @@ except ImportError as e:
    #? #################### MEMORY API ##############################
    
    
+import os
 from threading import Lock
 
 from ursina import (
@@ -1362,19 +1363,23 @@ class StateMachineAPI:
 class CacheAPI:
     
     def __init__(self, cache_path=None):
-        try:
-            self.CACHEPATH = cache_path
-            if not self.CacheExists():
-                import os
-                os.makedirs(cache_path)
-        except Exception:
-            pass
+        self.CACHEPATH = cache_path if cache_path else "./cache"
+        self._ensure_cache_directory()
+    
+    def _ensure_cache_directory(self):
+        """Stellt sicher, dass das Cache-Verzeichnis existiert"""
+        if self.CACHEPATH:
+            try:
+                os.makedirs(self.CACHEPATH, exist_ok=True)
+            except Exception as e:
+                print(f"Fehler beim Erstellen des Cache-Verzeichnisses: {e}")
     
     def SetCachePath(self, path):
+        """Setzt den Cache-Pfad und erstellt das Verzeichnis falls nötig"""
+        if not path:
+            raise ValueError("Cache-Pfad darf nicht None oder leer sein")
         self.CACHEPATH = path
-        if not self.CacheExists():
-            import os
-            os.makedirs(path)
+        self._ensure_cache_directory()
         
         
     def WriteCacheFile(self, filename, content):
